{% comment %}
Place to add widgets, e.g. using:

Groups:
 - http://www.addthis.com/
 - http://sharethis.com/publishers/get-sharing-tools
 - http://www.shareaholic.com/publishers/get_share_button
 - http://share.lockerz.com/buttons/

Individual buttons:
 - https://twitter.com/about/resources/buttons
 - http://tweetmeme.com/about/retweet_button
 - https://developers.facebook.com/docs/reference/plugins/like/
 - https://developers.facebook.com/docs/share/
 - https://developer.linkedin.com/publishers
 - http://www.google.com/webmasters/+1/button/

{% endcomment %}
