{% extends "fluent_blogs/entry_archive.html" %}
{% load i18n %}

{% block meta-description %}{% blocktrans with month=month|date:"YEAR_MONTH_FORMAT" %}Archives of {{ month }}{% endblocktrans %}{% endblock %}

{% block title %}{% blocktrans with month=month|date:"YEAR_MONTH_FORMAT" %}Archives of {{ month }}{% endblocktrans %}{% endblock %}

{% block content_title %}<h1>{% blocktrans with month=month|date:"YEAR_MONTH_FORMAT" %}Archives of {{ month }}{% endblocktrans %}</h1>{% endblock %}

{% block content %}
  {{ block.super }}

  <h2>{% trans "Daily archives" %}</h2>
  <ul>
    {% for date in date_list %}
      <li>
        <a href="./{{ date|date:"d" }}/" rel="archives">{{ date|date:"DATE_FORMAT" }}</a>
      </li>
    {% endfor %}
  </ul>
{% endblock %}
